@@ -368,6 +368,8 @@ class SeqLabPostProcessor(IPostProcessor):
 
         all_tp, all_fn, all_fp = 0, 0, 0
         for key in category_tp:
+            if key in self.config.ignore_labels:
+                continue
             tp, fn, fp = category_tp[key], category_fn[key], category_fp[key]
             all_tp += tp
             all_fn += fn
@@ -394,7 +396,7 @@ class SeqLabPostProcessor(IPostProcessor):
             entity_info
 
         """
-        if not sub_tokens_index or not label:
+        if (not sub_tokens_index) or (not label) or (label in self.config.ignore_labels):
             return {}
         start = offset_mapping[sub_tokens_index[0]][0]
         end = offset_mapping[sub_tokens_index[-1]][1]
